@@ -29,7 +29,6 @@
 #include <string.h>
 #include <stdlib.h>
 #include <libgnome/gnome-program.h>
-#include <libgnome/gnome-help.h>
 #include <libgnomeui/gnome-about.h>
 #include <libgnomeui/gnome-stock-icons.h>
 #include <gdk/gdkx.h>
@@ -786,7 +785,7 @@ terminal_window_init (TerminalWindow *window)
                                TRUE);                                      
   
   g_signal_connect_after (G_OBJECT (window->priv->notebook),
-                          "select_page",
+                          "switch_page",
                           G_CALLBACK (notebook_page_selected_callback),
                           window);
   
@@ -1676,8 +1675,6 @@ terminal_window_set_active (TerminalWindow *window,
 #endif
   terminal_window_set_size (window, screen, TRUE);
   
-  gtk_widget_grab_focus (terminal_screen_get_widget (window->priv->active_term));
-
   fill_in_config_picker_submenu (window);
   fill_in_new_term_submenus (window);
   update_zoom_items (window);
@@ -2600,17 +2597,7 @@ static void
 help_callback (GtkWidget      *menuitem,
                TerminalWindow *window)
 {
-  GError *err;
-
-  err = NULL;  
-  gnome_help_display ("gnome-terminal", NULL, &err);
-
-  if (err != NULL)
-    {
-      terminal_util_show_error_dialog (GTK_WINDOW (window), NULL,
-                                       _("There was an error displaying help: %s"), err->message);
-      g_error_free (err);
-    }
+  terminal_util_show_help (NULL, GTK_WINDOW (window));
 }
 
 static void
@@ -2623,6 +2610,7 @@ about_callback (GtkWidget      *menuitem,
 
   const char *authors[] = {
     "Havoc Pennington <hp@redhat.com>",
+    "Mariano Su\303\241rez-Alvarez <msuarezalvarez@arnet.com.ar>",
     NULL
   };
   const char *documenters [] = {
